@@ -4,11 +4,12 @@ package App::ElasticSearch::Utilities::QueryString::FileExpansion;
 use strict;
 use warnings;
 
-our $VERSION = '6.5'; # VERSION
+our $VERSION = '6.6'; # VERSION
 
 use CLI::Helpers qw(:output);
 use File::Slurp::Tiny qw(read_lines);
-use Ref::Util qw(is_hashref);
+use JSON::MaybeXS;
+use Ref::Util qw(is_ref is_arrayref is_hashref);
 use Text::CSV_XS;
 use namespace::autoclean;
 
@@ -18,9 +19,10 @@ with 'App::ElasticSearch::Utilities::QueryString::Plugin';
 sub _build_priority { 10; }
 
 my %parsers = (
-    txt => \&_parse_txt,
-    dat => \&_parse_txt,
-    csv => \&_parse_csv,
+    txt  => \&_parse_txt,
+    dat  => \&_parse_txt,
+    csv  => \&_parse_csv,
+    json => \&_parse_json,
 );
 
 
@@ -28,18 +30,18 @@ sub handle_token {
     my($self,$token) = @_;
 
     if( my ($term,$match) = split /\:/, $token, 2 ) {
-        if( defined $match && $match =~ /(.*\.(\w{3,4}))(?:\[(-?\d+)\])?$/) {
+        if( defined $match && $match =~ /(.*\.(\w{3,4}))(?:\[([^\]]+)\])?$/) {
             my($file,$type,$col) = ($1,$2,$3);
             $col //= -1;
             $type = lc $type;
-            verbose({level=>2,color=>'magenta'}, sprintf "# %s attempt of %s type, %s[%d] %s",
+            verbose({level=>2,color=>'magenta'}, sprintf "# %s attempt of %s type, %s[%s] %s",
                 $self->name, $type, $file, $col, -f $file ? 'exists' : 'does not exist'
             );
             if( exists $parsers{$type} && -f $file ) {
                 my $uniq = $parsers{$type}->($file,$col);
                 if (defined $uniq && is_hashref($uniq) && scalar(keys %$uniq)) {
                     verbose({color=>'cyan'},
-                        sprintf "# FILE:%s[%d] contained %d unique elements.",
+                        sprintf "# FILE:%s[%s] contained %d unique elements.",
                         $file,
                         $col,
                         scalar(keys %$uniq),
@@ -86,6 +88,51 @@ sub _parse_txt {
     return \%uniq;
 }
 
+sub _parse_json {
+    my ($file,$field) = @_;
+
+    die "For new line delimited JSON, please specify the key, ie <field>:$file\[key.path.i.want\]"
+        if $field eq "-1";
+
+    my %uniq = ();
+    my $line = 0;
+    my @path = split /\./, $field;      # Supports key.subkey.subsubkey format
+    JSON_LINE: foreach my $json ( read_lines($file) ) {
+        $line++;
+        my $data;
+        eval {
+            $data = decode_json($json);
+            1;
+        } or do {
+            my $err = $@;
+            output({stderr=>1,color=>'yellow'}, sprintf "Invalid JSON in %s, line %d: %s",
+                $file,
+                $line,
+                $err,
+            );
+            verbose({stderr=>1,color=>'magenta',indent=>1}, $json);
+            next;
+        };
+        # Walk the path
+        foreach my $k (@path) {
+            next JSON_LINE unless exists $data->{$k};
+            $data = $data->{$k};
+        }
+        # At this point $data should contain our values
+        if( is_arrayref($data) ) {
+            $uniq{$_} = 1 for grep { !is_ref($_) } @{ $data };
+        }
+        elsif( !is_ref($data) ) {
+            $uniq{$data} = 1;
+        }
+    }
+
+    die "Expected newline-delimited JSON in $file, but it was empty or didn't contain '$field'"
+        unless keys %uniq;
+
+    return \%uniq;
+}
+
 1;
 
 __END__
@@ -98,13 +145,13 @@ App::ElasticSearch::Utilities::QueryString::FileExpansion - Build a terms query
 
 =head1 VERSION
 
-version 6.5
+version 6.6
 
 =head1 SYNOPSIS
 
 =head2 App::ElasticSearch::Utilities::QueryString::FileExpansion
 
-If the match ends in .dat, .txt, or .csv, then we attempt to read a file with that name and OR the condition:
+If the match ends in .dat, .txt, .csv, or .json then we attempt to read a file with that name and OR the condition:
 
     $ cat test.dat
     50  1.2.3.4
@@ -128,14 +175,24 @@ Or
     1.2.3.6
     1.2.3.7
 
+Or
+
+    $ cat test.json
+    { "ip": "1.2.3.4" }
+    { "ip": "1.2.3.5" }
+    { "ip": "1.2.3.6" }
+    { "ip": "1.2.3.7" }
+
 We can source that file:
 
-    src_ip:test.dat => src_ip:(1.2.3.4 1.2.3.5 1.2.3.6 1.2.3.7)
+    src_ip:test.dat      => src_ip:(1.2.3.4 1.2.3.5 1.2.3.6 1.2.3.7)
+    src_ip:test.json[ip] => src_ip:(1.2.3.4 1.2.3.5 1.2.3.6 1.2.3.7)
 
 This make it simple to use the --data-file output options and build queries
 based off previous queries. For .txt and .dat file, the delimiter for columns
 in the file must be either a tab, comma, or a semicolon.  For files ending in
-.csv, Text::CSV_XS is used to accurate parsing of the file format.
+.csv, Text::CSV_XS is used to accurate parsing of the file format.  Files
+ending in .json are considered to be newline-delimited JSON.
 
 You can also specify the column of the data file to use, the default being the last column or (-1).  Columns are
 B<zero-based> indexing. This means the first column is index 0, second is 1, ..  The previous example can be rewritten
@@ -146,6 +203,21 @@ as:
 or:
     src_ip:test.dat[-1]
 
+For newline delimited JSON files, you need to specify the key path you want to extract from the file.  If we have a
+JSON source file with:
+
+    { "first": { "second": { "third": [ "bob", "alice" ] } } }
+    { "first": { "second": { "third": "ginger" } } }
+    { "first": { "second": { "nope":  "fred" } } }
+
+We could search using:
+
+    actor:test.json[first.second.third]
+
+Which would expand to:
+
+    { "terms": { "actor": [ "alice", "bob", "ginger" ] } }
+
 This option will iterate through the whole file and unique the elements of the list.  They will then be transformed into
 an appropriate L<terms query|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/query-dsl-terms-query.html>.
 
